package javax.crypto.spec;

import java.math.BigInteger;
import java.security.spec.KeySpec;

/**
 * This class specifies a Diffie-Hellman public key with its associated parameters.
 *
 * @see DHPrivateKeySpec
 */
public class DHPublicKeySpec
    implements KeySpec
{
    private BigInteger  y;
    private BigInteger  p;
    private BigInteger  g;

    /**
     * Constructor that takes a public value  y</code>, a prime
     * modulus  p</code>, and a base generator  g</code>.
     */
    public DHPublicKeySpec(
        BigInteger  y,
        BigInteger  p,
        BigInteger  g)
    {
        this.y = y;
        this.p = p;
        this.g = g;
    }

    /**
     * Returns the public value  y</code>.
     *
     * @return the public value  y</code>
     */
    public BigInteger getY()
    {
        return y;
    }

    /**
     * Returns the prime modulus  p</code>.
     *
     * @return the prime modulus  p</code>
     */
    public BigInteger getP()
    {
        return p;
    }

    /**
     * Returns the base generator  g</code>.
     *
     * @return the base generator  g</code>
     */
    public BigInteger getG()
    {
        return g;
    }
}
