package org.bouncycastle.jce.cert;

/**
 * A specification of  CertStore</code> parameters.<br />
 * <br />
 * The purpose of this interface is to group (and provide type safety for) 
 * all  CertStore</code> parameter specifications. All 
 *  CertStore</code> parameter specifications must implement this 
 * interface.  <br />
 * <br />
 * Typically, a  CertStoreParameters</code> object is passed as a parameter
 * to one of the {@link CertStore#getInstance CertStore.getInstance} methods. 
 * The  getInstance</code> method returns a  CertStore</code> that
 * is used for retrieving  Certificate</code>s and  CRL</code>s. The 
 *  CertStore</code> that is returned is initialized with the specified 
 * parameters. The type of parameters needed may vary between different types 
 * of  CertStore</code>s.
 *
 * @see CertStore#getInstance
 **/
public interface CertStoreParameters extends Cloneable
{
    /**
     * Makes a copy of this  CertStoreParameters</code>.<br />
     * <br />
     * The precise meaning of "copy" may depend on the class of 
     * the  CertStoreParameters</code> object. A typical implementation 
     * performs a "deep copy" of this object, but this is not an absolute 
     * requirement. Some implementations may perform a "shallow copy" of some 
     * or all of the fields of this object.<br />
     * <br />
     * Note that the  CertStore.getInstance</code> methods make a copy
     * of the specified  CertStoreParameters</code>. A deep copy
     * implementation of  clone</code> is safer and more robust, as it 
     * prevents the caller from corrupting a shared  CertStore</code> by
     * subsequently modifying the contents of its initialization parameters. 
     * However, a shallow copy implementation of  clone</code> is more 
     * appropriate for applications that need to hold a reference to a
     * parameter contained in the  CertStoreParameters</code>. For example,
     * a shallow copy clone allows an application to release the resources of 
     * a particular  CertStore</code> initialization parameter immediately,
     * rather than waiting for the garbage collection mechanism. This should 
     * be done with the utmost care, since the  CertStore</code> may still 
     * be in use by other threads.<br />
     * <br />
     * Each subclass should state the precise behavior of this method so
     * that users and developers know what to expect.
     *
     * @return a copy of this  CertStoreParameters</code>
     */
    public Object clone();
}
